@@ -18,6 +18,7 @@ const (
 	OpenShiftConsoleDeploymentName      = OpenShiftConsoleName
 	OpenShiftConsoleServiceName         = OpenShiftConsoleName
 	OpenShiftConsoleRouteName           = OpenShiftConsoleName
+	OpenShiftConsoleDownloadsRouteName  = "downloads"
 	OAuthClientName                     = OpenShiftConsoleName
 	OpenShiftConfigManagedNamespace     = "openshift-config-managed"
 	OpenShiftConfigNamespace            = "openshift-config"
@@ -26,4 +27,6 @@ const (
 	TrustedCABundleKey                  = "ca-bundle.crt"
 	TrustedCABundleMountDir             = "/etc/pki/ca-trust/extracted/pem"
 	TrustedCABundleMountFile            = "tls-ca-bundle.pem"
+	OCCLIDownloadsCustomResourceName    = "oc-cli-downloads"
+	ODOCLIDownloadsCustomResourceName   = "odo-cli-downloads"
 )
